@@ -43,9 +43,9 @@ def video_2_gif(path: str, size: tuple = (480, 320), fps: int = None, mpy=None):
     :return: None
     """
     file_name = '.'.join(os.path.basename(path).split('.')[:-1]) + '.gif'
-    dir_name = dir_char.join(os.path.abspath(path).split(dir_char)[:-1]) + dir_char
+    dir_name = os.path.abspath(os.path.dirname(path))
     ct = mpy.VideoFileClip(path) if not size else mpy.VideoFileClip(path).resize(size)
-    ct.write_gif(dir_name + file_name, fps=fps) if fps else ct.write_gif(dir_name + file_name)
+    ct.write_gif(os.path.join(dir_name, file_name), fps=fps)
 
 
 @VideoWrapper
@@ -67,9 +67,9 @@ def rm_audio(path: str, mpy=None):
         file_name = '.'.join(file_name[:-1]) + '.mp4'
     else:
         file_name += '_rm_audio'
-    dir_name = dir_char.join(os.path.abspath(path).split(dir_char)[:-1]) + dir_char
+    dir_name = os.path.abspath(os.path.dirname(path))
     ct = mpy.VideoFileClip(path).set_audio(None)
-    ct.write_videofile(dir_name + file_name)
+    ct.write_videofile(os.path.join(dir_name, file_name))
 
 
 @VideoWrapper
@@ -85,9 +85,9 @@ def tomp4(path: str, mpy=None):
     """
     file_name = os.path.basename(path)
     file_name = '.'.join(file_name.split('.')[:-1]) + '.mp4' if '.' in file_name else file_name + '.mp4'
-    dir_name = dir_char.join(os.path.abspath(path).split(dir_char)[:-1]) + dir_char
+    dir_name = os.path.abspath(os.path.dirname(path))
     ct = mpy.VideoFileClip(path)
-    ct.write_videofile(dir_name + file_name, audio_codec='aac')
+    ct.write_videofile(os.path.join(dir_name, file_name))
 
 
 @VideoWrapper
@@ -101,8 +101,8 @@ def video_2_mp3(path: str, mpy=None):
     """
     file_name = os.path.basename(path)
     file_name = '.'.join(file_name[:-1].split('.')) + '.mp3' if '.' in file_name else file_name + '.mp3'
-    dir_name = dir_char.join(os.path.abspath(path).split(dir_char)[:-1]) + dir_char
-    mpy.VideoFileClip(path).audio.write_audiofile(dir_name + file_name)
+    dir_name = os.path.abspath(os.path.dirname(path))
+    mpy.VideoFileClip(path).audio.write_audiofile(os.path.join(dir_name, file_name))
 
 
 @VideoWrapper
@@ -119,8 +119,8 @@ def set_video_audio(v_path: str, a_path: str, mpy=None):
     """
     file_name = os.path.basename(v_path)
     file_name = '.'.join(file_name.split('.')[:-1]) + '_sta.mp4' if '.' in file_name else file_name + '_sta.mp4'
-    dir_name = dir_char.join(os.path.abspath(v_path).split(dir_char)[:-1]) + dir_char
+    dir_name = os.path.abspath(os.path.dirname(v_path))
     v = mpy.VideoFileClip(v_path)
     a = mpy.AudioFileClip(a_path)
     v = v.set_audio(a)
-    v.write_videofile(dir_name + file_name, audio_codec='aac')
+    v.write_videofile(os.path.join(dir_name, file_name), audio_codec='aac')
